.. _toolkits-index:

.. _toolkits:

########
Toolkits
########

Toolkits are collections of application-specific functions that extend
Matplotlib.

.. _toolkit_mplot3d:

mplot3d
=======

:mod:`mpl_toolkits.mplot3d` provides some basic 3D
plotting (scatter, surf, line, mesh) tools.  Not the fastest or most feature
complete 3D library out there, but it ships with Matplotlib and thus may be a
lighter weight solution for some use cases. Check out the
:doc:`mplot3d tutorial </tutorials/toolkits/mplot3d>` for more
information.

.. figure:: ../../gallery/mplot3d/images/sphx_glr_contourf3d_2_001.png
   :target: ../../gallery/mplot3d/contourf3d_2.html
   :align: center
   :scale: 50

.. toctree::
    :maxdepth: 2

    mplot3d/index.rst
    mplot3d/faq.rst

Links
-----
* mpl3d API: :ref:`toolkit_mplot3d-api`

.. include:: axes_grid1.rst
   :start-line: 1

.. include:: axisartist.rst
   :start-line: 1

.. include:: axes_grid.rst
   :start-line: 1
